@@ -1,10 +1,10 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: arp.tcl,v 1.15 1999/01/04 23:05:31 jfontain Exp $}
+set rcsId {$Id: arp.tcl,v 1.16 1999/01/16 20:31:02 jfontain Exp $}
 
 
-package provide arp 1.2
+package provide arp 1.3
 package require network 1.2
 
 namespace eval arp {
@@ -18,28 +18,11 @@ namespace eval arp {
         4,label flags 4,type ascii 4,message {entry flags (C: complete, M: permanent, P: published)}
         5,label interface 5,type ascii 5,message {networking interface}
         sort {0 increasing}
-        helpText {
-This is a view of the network Address Resolution Protocol cache for the system (tested on IPv4 only).
-
-Host addresses are looked up and converted to official names when possible.
-
-Hardware addresses are decoded, with a full name (from the /etc/ethers file if present, read once when the application is started), or with the vendor name for the first 3 bytes (from the vendor.txt file in the arp module sub directory).
-Note: you may update the vendor.txt file yourself by opening it from the http://pax.cavebear.com/CaveBear/Ethernet/ page and saving it as a text file under the vendor.txt name in the arp module sub directory (no editing needed).
-
-Module options:
-
--n (--numeric): display numerical addresses instead of trying to determine symbolic host or network names.
--r (--remote) [user@]host: remote monitoring using "user" as logname on remote host "host" (rsh facilities must be properly setup). If user is not specified, current user is used as logname on remote host.
-
-Examples:
-
-$ moodss arp --numeric
-$ moodss -- arp -n
-$ moodss arp -r jdoe@foo.bar.com
-$ moodss arp --remote foo.bar.com
-        }
         switches {-n 0 --numeric 0 -r 1 --remote 1}
     }
+    set file [open [file join $packageDirectory arp.htm]]
+    set data(helpText) [read $file]                                                           ;# initialize HTML help data from file
+    close $file
 
     proc initialize {optionsName} {
         upvar $optionsName options
