@@ -1,16 +1,15 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: diskstats.tcl,v 1.9 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: diskstats.tcl,v 1.12 1999/01/04 22:26:57 jfontain Exp $}
 
 package provide diskstats 1.0
-
 package require filesystem
 
 namespace eval diskstats {
 
     set file [open /proc/version]                                                                      ;# first check kernel version
-    set version [lindex [gets $file] 2]
+    regexp {^[0-9\.]+} [lindex [gets $file] 2] version                             ;# ignore extra characters, such as in 2.2.0-pre1
     close $file
 
     if {[package vcompare $version 2]<0} {
@@ -46,7 +45,7 @@ SCSI support is not very well tested, for lack of hardware: please report proble
             5,label device 5,type ascii 5,message {device (sd*: SCSI, hd*: IDE)}
             6,label type 6,type ascii 6,message {type or media}
             7,label size 7,type integer 7,message {size in KiloBytes}
-            8,label model 8,type ascii 8,message {model description}
+            8,label model 8,type ascii 8,message {model description} 8,anchor left
             views {
                 {visibleColumns {0 1 2 3 4} sort {0 increasing}}
                 {visibleColumns {0 5 6 7 8} sort {0 increasing}}
