@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: html.tcl,v 1.22 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: html.tcl,v 1.23 1999/01/16 16:21:55 jfontain Exp $}
 
 # use bold and smaller sizes than the HTML library default ones for headers
 array set HMtag_map {
@@ -26,22 +26,48 @@ array set HMinsert_map {
     pre "\n\n" /pre "\n\n"
 }
 
+unset HMevents(Enter)                                                     ;# prevent links highlighting, try to behave like Netscape
+unset HMevents(Leave)
+unset HMevents(1)
+set HMevents(ButtonRelease-1) {-foreground darkblue}
+
+proc HMlink_callback {widget reference} {                                                          ;# supply link callback procedure
+    global htmlHelpDataText
+
+    if {![string match #* $reference]} return                                                 ;# can only handle internal references
+    HMgoto $htmlHelpDataText [string trimleft $reference #]                                   ;# always update help data text widget
+}
+
+proc HMset_image {widget label source} {                                                          ;# supply image handling procedure
+    if {\
+        [catch {image create photo -file $source} image]&&\
+        [catch {image create photo -file [file join /usr/doc/moodss-$::applicationVersion $source]} image]\
+    } return                                                  ;# local directory and rpm documentation directory searched and failed
+    bind $label <Destroy> "image delete $image"                      ;# setup binding so that image is deleted as label is destroyed
+    HMgot_image $label $image                                                               ;# got the image for the specified label
+}
+
 proc customHMTLConfiguration {path} {                                             ;# make HTML text widget behave more like Netscape
     $path tag configure mark -foreground black                                                        ;# override list markers color
     $path tag configure link -borderwidth 1 -foreground blue -underline 1           ;# override hypertext links border and underline
     set ::HM${path}(S_symbols) oooooo\xd7\xb0>:\xb7                                   ;# use simple circles for list element markers
 }
 
-proc helpWindow {} {
+proc setupHelpWindow {toplevel} {
+    if {[winfo exists $toplevel]} {
+        wm deiconify $toplevel
+        raise $toplevel
+        return 0
+    }
+    toplevel $toplevel
+    wm group $toplevel .                                             ;# for proper window manager (windowmaker for example) behavior
+    return 1
+}
+
+proc generalHelpWindow {} {
     global htmlHelpDataText
 
-    if {[winfo exists .topHelp]} {
-        wm deiconify .topHelp
-        raise .topHelp
-        return
-    }
-    toplevel .topHelp
-    wm group .topHelp .                                              ;# for proper window manager (windowmaker for example) behavior
+    if {![setupHelpWindow .topHelp]} return
     wm title .topHelp {moodss: Global Help}
     frame .topHelp.bound                      ;# create a frame for bindings that otherwise would propagate to all toplevel children
 
@@ -88,23 +114,32 @@ proc helpWindow {} {
     update idletasks
 }
 
-unset HMevents(Enter)                                                     ;# prevent links highlighting, try to behave like Netscape
-unset HMevents(Leave)
-unset HMevents(1)
-set HMevents(ButtonRelease-1) {-foreground darkblue}
-
-proc HMlink_callback {widget reference} {                                                          ;# supply link callback procedure
+proc moduleHelpWindow {name} {
     global htmlHelpDataText
 
-    if {![string match #* $reference]} return                                                 ;# can only handle internal references
-    HMgoto $htmlHelpDataText [string trimleft $reference #]                                   ;# always update help data text widget
-}
+    ### use same toplevel as general help as we can handle only 1 widget at a time (see link callback procedure above) ###
+    if {![setupHelpWindow .topHelp]} return
+    wm title .topHelp "moodss: $name Module Help"
+    frame .topHelp.bound                      ;# create a frame for bindings that otherwise would propagate to all toplevel children
 
-proc HMset_image {widget label source} {                                                          ;# supply image handling procedure
-    if {\
-        [catch {image create photo -file $source} image]&&\
-        [catch {image create photo -file [file join /usr/doc/moodss-$::applicationVersion $source]} image]\
-    } return                                                  ;# local directory and rpm documentation directory searched and failed
-    bind $label <Destroy> "image delete $image"                      ;# setup binding so that image is deleted as label is destroyed
-    HMgot_image $label $image                                                               ;# got the image for the specified label
+    set widget [new scroll text .topHelp -horizontal 0]
+    pack $widget::($widget,path) -fill both -expand 1
+
+    bind .topHelp.bound <Destroy> "delete $widget"
+
+    set htmlHelpDataText $composite::($widget,scrolled,path)                                          ;# setup and display help text
+    $htmlHelpDataText configure -cursor watch                                             ;# show that we are busy for user feedback
+    update idletasks
+
+    HMinit_win $htmlHelpDataText
+    customHMTLConfiguration $htmlHelpDataText
+
+    $htmlHelpDataText configure -state normal
+    HMparse_html [modules::helpHTMLData $name] "HMrender $htmlHelpDataText"
+    if {![winfo exists .topHelp]} return                            ;# user may have destroyed the window through the window manager
+    $htmlHelpDataText configure -state disabled
+    HMset_state $htmlHelpDataText -stop 1                                                    ;# stop rendering previous page if busy
+
+    $htmlHelpDataText configure -cursor {}
+    update idletasks
 }
