@@ -1,6 +1,6 @@
 set htmlHelpContents {
-<BODY>
 <HTML>
+<BODY>
 <UL>
 <LI>
 <A HREF="#about">1. About this document</A></LI>
@@ -116,6 +116,7 @@ drag'n'drop, and viewer quick destruction through trash icon drag'n'drop
 operation. A new menu for empty viewer creation was also added.
 <P>Versions 6.0 and up support command line arguments per module, data
 table column anchoring in module configuration and automatic module discovery.
+<P>Versions 6.1 and up support HTML formatted data for modules.
 <P>Since module data access is entirely customizable (through C code, Tcl,
 HTTP, ...) and since several modules can be loaded at once, applications
 for moodss become limitless. For example, comparing a remote database server
@@ -145,7 +146,7 @@ rpm file (available (starting with 4.4) at <A HREF="http://www.multimania.com/jf
 for installation. It requires the tcl, tk, blt and tktable rpms (see INSTALL
 file for more information). Unless you want to work on the moodss source
 code, you can skip the rest of this section.
-<P>For the current version (6.0), the following packages must be installed
+<P>For the current version (6.1), the following packages must be installed
 before attempting to install moodss (make sure to check the INSTALL file
 for the latest information):
 <UL>
@@ -230,7 +231,7 @@ Soon after the application launch, tabular data is displayed in one or
 more tkTable widgets with automatic scroll bars, between the menu bar,
 the drop sites with graphical viewers, summary table, free text and trash
 icons and a message area, as one can see below:
-<CENTER><PRE><IMG SRC="moodss1.gif" ALT="moodss initial main window view" HEIGHT=501 WIDTH=501></PRE></CENTER>
+<CENTER><PRE><IMG SRC="moodss1.gif" ALT="moodss initial main window view" NOSAVE HEIGHT=501 WIDTH=501></PRE></CENTER>
 The message area is used to display status information, such as when the
 data is being updated, and help information, as the user moves the mouse
 pointer over sensitive areas, such as table column headers. Further help
@@ -244,7 +245,7 @@ or gracefully quit the moodss application.
 <P>The <I>Options</I> menu (may not exist, see below) contains the <I>Poll
 time</I> entry which when selected launches the corresponding dialog box,
 as shown below:
-<CENTER><PRE><IMG SRC="moodss2.gif" ALT="poll time dialog box" HEIGHT=140 WIDTH=161></PRE></CENTER>
+<CENTER><PRE><IMG SRC="moodss2.gif" ALT="poll time dialog box" NOSAVE HEIGHT=140 WIDTH=161></PRE></CENTER>
 The user can select a new poll time among the module choices from a spin
 entry widget, or directly type in a new value, as long as it is not smaller
 than the module minimum poll time, in which case a message dialog box warns
@@ -287,31 +288,31 @@ in advance...</I>
 <CENTER><TABLE COLS=2 WIDTH="100%" NOSAVE >
 <TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
 <TD NOSAVE>
-<CENTER><PRE><IMG SRC="hgraph.gif" ALT="graph viewer sample" HEIGHT=200 WIDTH=300></PRE></CENTER>
+<CENTER><PRE><IMG SRC="hgraph.gif" ALT="graph viewer sample" NOSAVE HEIGHT=200 WIDTH=300></PRE></CENTER>
 </TD>
 
 <TD>
-<PRE><IMG SRC="hoverbar.gif" ALT="overlap bar chart viewer sample" HEIGHT=200 WIDTH=300></PRE>
+<PRE><IMG SRC="hoverbar.gif" ALT="overlap bar chart viewer sample" NOSAVE HEIGHT=200 WIDTH=300></PRE>
 </TD>
 </TR>
 
 <TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
 <TD NOSAVE>
-<PRE><IMG SRC="hsidebar.gif" ALT="side bar chart viewer sample" HEIGHT=200 WIDTH=300></PRE>
+<PRE><IMG SRC="hsidebar.gif" ALT="side bar chart viewer sample" NOSAVE HEIGHT=200 WIDTH=300></PRE>
 </TD>
 
 <TD>
-<PRE><IMG SRC="hstackbr.gif" ALT="stacked bar chart viewer sample" HEIGHT=200 WIDTH=300></PRE>
+<PRE><IMG SRC="hstackbr.gif" ALT="stacked bar chart viewer sample" NOSAVE HEIGHT=200 WIDTH=300></PRE>
 </TD>
 </TR>
 
 <TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
 <TD NOSAVE>
-<PRE><IMG SRC="h2dpie.gif" ALT="2D pie chart viewer sample" HEIGHT=200 WIDTH=300></PRE>
+<PRE><IMG SRC="h2dpie.gif" ALT="2D pie chart viewer sample" NOSAVE HEIGHT=200 WIDTH=300></PRE>
 </TD>
 
 <TD>
-<PRE><IMG SRC="h3dpie.gif" ALT="3D pie chart viewer sample" HEIGHT=200 WIDTH=300></PRE>
+<PRE><IMG SRC="h3dpie.gif" ALT="3D pie chart viewer sample" NOSAVE HEIGHT=200 WIDTH=300></PRE>
 </TD>
 </TR>
 </TABLE></CENTER>
@@ -334,17 +335,17 @@ at any time.
 <CENTER><TABLE WIDTH="100%" NOSAVE >
 <TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
 <TD WIDTH="58%" NOSAVE>
-<PRE><IMG SRC="hsumtbl.gif" ALT="summary table viewer sample" HEIGHT=200 WIDTH=350></PRE>
+<PRE><IMG SRC="hsumtbl.gif" ALT="summary table viewer sample" NOSAVE HEIGHT=200 WIDTH=350></PRE>
 </TD>
 
 <TD WIDTH="42%" NOSAVE>
-<PRE><IMG SRC="hfreetxt.gif" ALT="free text viewer sample" HEIGHT=200 WIDTH=250></PRE>
+<PRE><IMG SRC="hfreetxt.gif" ALT="free text viewer sample" NOSAVE HEIGHT=200 WIDTH=250></PRE>
 </TD>
 </TR>
 </TABLE></CENTER>
 Here is a screen shot of loaded <I>ps</I> and <I>cpustats</I> modules with
 several graphical viewers:
-<CENTER><PRE><IMG SRC="moodss3.gif" ALT="moodss window with graph data viewers" HEIGHT=514 WIDTH=524></PRE></CENTER>
+<CENTER><PRE><IMG SRC="moodss3.gif" ALT="moodss window with graph data viewers" NOSAVE HEIGHT=514 WIDTH=524></PRE></CENTER>
 All data viewers can be moved and resized thanks to handling areas in the
 data viewer borders. When moving the mouse pointer over these areas, the
 mouse cursor changes to indicate the possible action. Corner handles allow
@@ -360,13 +361,13 @@ small window manager functionality is useless, as it behaves like a basic
 window manager (let me know if it does not).
 <P>Here is another shot featuring a free text viewer with loaded <I>cpustats</I>
 and <I>memstats</I> modules:
-<CENTER><PRE><IMG SRC="moodss4.gif" ALT="moodss window with free text data viewer" HEIGHT=480 WIDTH=459></PRE></CENTER>
+<CENTER><PRE><IMG SRC="moodss4.gif" ALT="moodss window with free text data viewer" NOSAVE HEIGHT=480 WIDTH=459></PRE></CENTER>
 The <I>Help</I> menu contains <I>Global</I> help (actually launches an
-embedded HTML viewer with this very document), <I>Modules</I> help which
-displays all the loaded modules help texts, <I>Copyright</I> which displays
-the GPL (Gnu General Public License) document, <I>Source Versions </I>which
-display all the source code file names with their versions and <I>About</I>
-general information entries.
+embedded HTML viewer with this very document), <I>Modules</I> menu with
+one sub-menu per module (which displays the module's help data), <I>Copyright</I>
+which displays the GPL (Gnu General Public License) document, <I>Source
+Versions </I>which display all the source code file names with their versions
+and <I>About</I> general information entries.
 <H5>
 <A NAME="draganddrop"></A>5.1.1 Drag and drop</H5>
 Drag and drop in moodss tries to behave as the now familiar Windows functionality
@@ -540,6 +541,9 @@ command line after the -f (--file) switch / value pair.
 <LI>
 <B>-h</B> (or <B>--help</B>): display some help text and exit</LI>
 
+<LI>
+<B>-geometry</B>: set the initial geometry of the main window (a la X window)</LI>
+
 <LI>
 <B>-p</B> (or <B>--poll-time</B>): specify a poll time in seconds</LI>
 
