@@ -9,9 +9,9 @@ source utility.tcl
 
 startGatheringRCSIds
 
-set rcsId {$Id: moodss.tcl,v 1.141 1999/01/11 20:52:21 jfontain Exp $}
+set rcsId {$Id: moodss.tcl,v 1.143 1999/01/16 16:20:02 jfontain Exp $}
 
-set applicationVersion 6.0
+set applicationVersion 6.1
 
 source getopt.tcl
 
@@ -303,17 +303,18 @@ $canvas configure -background white -width $width -height $height -scrollregion
 
 set windowManager [new canvasWindowManager $canvas]
 
-if {[info exists initializer]} {
+if {[info exists ::geometry]} {                                                               ;# command line geometry was specified
+    wm geometry . $::geometry
+} elseif {[info exists initializer]} {
     foreach {width height} [record::sizes $initializer] {}                                   ;# used stored geometry for main window
+    wm geometry . ${width}x$height
 } else {
-    set width 400
-    set height 300
+    wm geometry . 400x300
 }
 
 image create photo applicationIcon -data [dataGraph::iconData]                                ;# use data graph icon for application
 wm iconwindow . [toplevel .icon]
 pack [label .icon.image -image applicationIcon]
-wm geometry . ${width}x$height
 
 if {!$readOnly} {
     pack [createDragAndDropZone .] -fill x
