@@ -1,14 +1,14 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: random.tcl,v 1.21 1999/01/05 22:13:54 jfontain Exp $}
+set rcsId {$Id: random.tcl,v 1.23 1999/01/16 20:31:02 jfontain Exp $}
 
 # module sample file with random data
 
 # corresponding pkgIndex.tcl file content:
 # package ifneeded random 4.0 "source [file join $dir random.tcl]"
 
-package provide random 4.0
+package provide random 4.1
 
 namespace eval random {                                                                    ;# namespace name must match package name
     # Module data is arranged in a single array that can be used by many views, such as tables, graphs, pies,...
@@ -36,7 +36,9 @@ namespace eval random {
     # - indexColumns: a list that specifies the columns required to uniquely identify a row in the table. It is optional and
     #   defaults to the column 0, unless of course you do not have a 0 column index, in which case it is mandatory to specify this
     #   list. When specified, all the columns in the list must be visible (see visibleColumns member above).
-    # - helpText: displayed when the module help is launched from the main window help menu.
+    # - helpText: displayed when the module help is launched from the main window help menu. Can be plain text or HTML formatted
+    #   (<HTML> and <BODY> tags required), in which case it is properly rendered in the module help window (note: tables, frames,
+    #   and may other tags are not supported: stick to formatted text at the moment).
     # - views: optional. If specified, it defines one or more views to be used in place of the default view. One table will be
     #   displayed per view. Each view is a list of array members, suitable as an argument to an "array set" command. For each view,
     #   2 members must be defined: visibleColumns and sort (syntax and usage are identical to the default table members).
@@ -55,22 +57,15 @@ namespace eval random {
         pollTimes {10 5 20 30 60 120 300}
         sort {1 decreasing}
         indexColumns {0 4}
-        helpText {
-This is a simple demonstration module for the moodss (Modular Object Oriented Dynamic SpreadSheet) utility. Most of the data is randomly generated.
-
-Data is presented in 2 tables: one for the CPU and memory usage, the other for disk usage.
-
-Module options:
-
--a (--asynchronous): simulates asynchronous module behavior by spontaneously self updating in a semi-random fashion, when time permits (erratic during full moon periods :^).
-        }
         views {
             {visibleColumns {0 1 3 4} sort {1 decreasing}}
             {visibleColumns {0 2 4} sort {2 decreasing}}
         }
         switches {-a 0 --asynchronous 0}
     }
-
+    set file [open [file join $packageDirectory random.htm]]                                ;# directory is set in pkgIndex.tcl file
+    set data(helpText) [read $file]                                   ;# initialize HTML help data from file in module sub-directory
+    close $file
 
     # The initialize procedure, if it exists, is invoked by the core before any update occurs (update procedure invocation if the
     # module is synchronous). It can be used for module setup, although it is rather redundant with inline module namespace code
