@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: utility.tcl,v 1.6 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: utility.tcl,v 1.7 1999/01/10 20:06:25 jfontain Exp $}
 
 proc minimum {a b} {return [expr {$a<$b?$a:$b}]}
 proc maximum {a b} {return [expr {$a>$b?$a:$b}]}
@@ -26,3 +26,11 @@ proc recordRCSId {variableName empty operation} {
     regsub {,v$} $file {} file
     set ::sourceVersion($file) $version
 }
+
+proc commaSeparatedString {words} {
+    for {set index 0} {$index<([llength $words]-1)} {incr index} {
+        append string "[lindex $words $index], "
+    }
+    append string [lindex $words $index]
+    return $string
+}
